//===================================================================================================
//
//	MainFrame.cpp
//
//	(c) 1996 by Apple Computer, Inc., all rights reserved.
//		(Print at 85% 9 pt Monaco)
//
//	History:
//		02/01/96	Damon Cokenias		Created
//
//===================================================================================================

//	Normally Nautilus plugins are embedded as icon and do not ever need to display as frame.
//	However, when a user embeds the plugin in a part other than Nautilus, or tries to open it as
//	the root part, a frame may be required.
//
//	The frame displayed contains a simple message saying something to the effect of "You can't
//	use this part, piss off."

#ifndef MAINFRAME_H
#include "MainFrame.h"
#endif

#ifndef PLUGINPART_H
#include "PluginPart.h"
#endif

#ifndef FWCONTXT_H
#include <FWContxt.h>
#endif

FW_DEFINE_AUTO (CMainFrame)

const FW_CRect		CMainFrame::kDefaultBounds (FW_kZeroPoint, FW_IntToFixed(360),
							FW_IntToFixed(100));

CMainFrame::CMainFrame (Environment* ev, ODFrame* odFrame, FW_CPresentation* presentation,
			CPluginStarterPart* part) :
	FW_CFrame (ev, odFrame, presentation, part),
	fPart (part)
{
	FW_END_CONSTRUCTOR
}


CMainFrame::~CMainFrame()
{
	FW_START_DESTRUCTOR
}

void CMainFrame::Draw (Environment* ev, ODFacet* odFacet, ODShape* invalidShape)
{

	FW_CViewContext				vc (ev, this, odFacet, invalidShape);
	FW_CString255				message;

	FW_CSharedLibraryResourceFile		resFile(ev);
	::FW_LoadStringByID (ev, resFile, kMainStrings, MULTISTRINGRES, kUselessPartString, message);

	FW_CRect			rect = GetBounds (ev);
	
	// A soothing pink
	FW_CRectShape::RenderRect (vc, rect, FW_kFill, FW_CColor (0xF0, 0xC0, 0xC0));

	rect.Inset (FW_IntToFixed (10), FW_IntToFixed (10));
	
	FW_CTextBoxShape::RenderTextBox (vc, message, rect, FW_CFont (FW_kHelvetica, FW_kBold,
			FW_IntToFixed (9)), FW_kTextBoxJustifyHCenter | FW_kTextBoxJustifyVCenter);
}

void CMainFrame::FrameShapeChanged (Environment* ev)
{
	FW_CFrame::FrameShapeChanged(ev);
	
	this->Invalidate(ev);
}

void CMainFrame::FacetAdded(Environment* ev, ODFacet* odFacet, unsigned short facetCount)
{
	FW_CAcquiredODShape askedShape = ::FW_NewODShape(ev, kDefaultBounds);
	this->RequestFrameShape(ev, askedShape);
	
	FW_CFrame::FacetAdded (ev, odFacet, facetCount);
}

