//===================================================================================================
//
//	TestCases.cpp
//
//	(c) 1996 by Apple Computer, Inc., all rights reserved.
//		(Print at 85% 9 pt Monaco)
//
//	History:
//		02/01/96	Damon Cokenias		Created
//		03/10/96	Damon Cokenias		Moved CountTestCases, GetTestCase and ExecuteTestCase from
//										PluginPart.cpp.  These routines will eventually be replaced
//										with a much more inteligent/easy to maintain solution.
//
//===================================================================================================

#ifndef TESTCASES_H
#include "TestCases.h"
#endif

#ifndef PLUGINPART_H
#include "PluginPart.h"
#endif

#ifndef NAUTILUSGLUE_H
#include <NautilusGlue.h>
#endif

#ifndef FWEXCEPT_H
#include <FWExcLib.h>
#endif

#include <stdlib.h>

//	This method is called by Nautilus.  It should return the number of test cases supported by
//	this plugin.
short CPluginStarterPart::CountTestCases (Environment* ev)
{
	return 1;
}

//	GetTestCase is called once for each test case provided by the plugin (the number of which was
//	returned by 'CountTestCases').  A test case is a SOM object containing a string to be
//	displayed to the user and an ID number.  The ID number is entirely for the plugin's use.
//
//	This implementation just stores the index (1..n) of the test case being requested in the ID
//	field.
//
//	Note that a test case object is a ref-counted object.  When its ref-count drops to zero it
//	will self-destruct.  When Nautilus asks a plugin to execute a particular test case, it will
//	pass back a reference to an object created by this routine.  This allows the test writer to
//	subclass NautilusPluginXTN_SOMNautilusTestCase to attach fields/methods that may be usefull to
//	the test case.
//
//	For many purposes, the 'testID' field will allow for enough flexibility, however.

NautilusPluginXTN_SOMNautilusTestCase* CPluginStarterPart::GetTestCase (Environment* ev, short index)
{
	char*				name;
	
	switch (index) {
		case (1) : name = "My First Test Case"; break;
		
		// Add more test cases here...
		
		default : name = "ERROR! Bad test case index!"; break;
	};

	NautilusPluginXTN_SOMNautilusTestCase*		somTestCase =
											new NautilusPluginXTN_SOMNautilusTestCase;
	
	FW_ASSERT (somTestCase);
	
	somTestCase -> _set_testName (ev, name);
	somTestCase -> _set_testID (ev, index);
	
	return somTestCase;
}

//	ExecuteTestCase is called to execute a particular test.  The requested test case is described by
//	a reference to the SOM test case object returned by GetTestCase (above).
//
//	This implementation just switches off the ID and calls the appropriate routine.  Note the
//	N_Environment parameter.  This parameter is required by the various macros defined in
//	NautilusGlue.h.
//
N_ETestResult CPluginStarterPart::ExecuteTestCase (Environment* ev,
		NautilusPluginXTN_SOMNautilusTestCase* testCase)
{
	FW_ASSERT (testCase);
	
	short				testID = testCase -> _get_testID (ev);
	N_Environment		nev;
	N_ETestResult		result = N_kPluginAborted;
	
	nev.ev = ev;
	nev.pluginID = fPluginID;
	nev.extension = fServices;
	
	switch (testID) {
	
		case (1) : result = MyFirstTestCase (nev); break;
	
		// Add more test cases here

		default: FW_CDebugConsole::DebugMessage ("Invalid test case requested!"); break;
	};
	
	return result;
}

// --------------------------------------------------------------------------------------------------
//
//	Replace this test case with your own.
//
//	The test below performs a simple test of GetHandleSize

N_ETestResult MyFirstTestCase (const N_Environment& nev)
{
	const Size		kTestHandleSize = 1024;
	
	N_CHECKPOINT_START;		// Every test case must have this checkpoint
	
	N_CHECKPOINT ("Allocate handle");
	Handle			h = NewHandle (kTestHandleSize);
	N_Verify (nev, (long) h, N_kNotEqualTo, 0, NULL, N_kFatal, N_kDisplayHex);
	
	N_CHECKPOINT ("Check handle size");
	N_Verify (nev, GetHandleSize (h), N_kEqualTo, kTestHandleSize);
	
	DisposeHandle (h);

	N_CHECKPOINT_END;		// Every test case must have this checkpoint
	return N_kTestPassed;
}

